@@ -1,9 +1,22 @@
 from enum import Enum
 
-
 # This comes from crosswire.org "Standard OSIS Codes for Bible Editions"
 # noinspection SpellCheckingInspection
+from typing import Dict
+
+
 class Version(Enum):
+    """Version is an Enum containing all of the currently known Ancient Language
+    and English versions of the Bible
+
+    :param name: the unique text identifier of the version
+    :type name: str
+    :param value: the unique numerical identifier of the version
+    :type value: int
+    :param title: the English title of the version
+    :type title: str
+    """
+
     # Ancient Language Editions
     STEPHANUS_GNT = "Steph"
     LATIN_VULGATE = "Vul"
@@ -103,12 +116,12 @@ class Version(Enum):
     YOUNGS_LITERAL = "YLT"
 
     @property
-    def title(self):
-        return _VERSION_TITLES.get(self)
+    def title(self) -> str:
+        return _VERSION_TITLES.get(self, "")
 
 
 # noinspection SpellCheckingInspection
-_VERSION_TITLES = {
+_VERSION_TITLES: Dict[Version, str] = {
     # Ancient Language Editions
     Version.STEPHANUS_GNT: "Stephanus GNT",
     Version.LATIN_VULGATE: "Latin Vulgate",
@@ -206,4 +219,4 @@ _VERSION_TITLES = {
     Version.YOUNGS_LITERAL: "Young's Literal Translation of the Bible",
 }
 
-DEFAULT_VERSION = Version.KING_JAMES
+DEFAULT_VERSION: Version = Version.KING_JAMES
